@@ -59,7 +59,7 @@ class AnkiCard:
         try:
             self.image = self.__download_word_image(*args,**kwargs)
         except:
-            self.image = Path(LangDeckGen.__file__).parent / 'placeholder.png' 
+            self.image = Path(LangDeckGen.__file__).parent / 'templates' / 'placeholder.png' 
             self.image = str(self.image)
         if not kwargs.get("PhrasesOnly"):
             self.sentence_audio = self.__generate_sentence_audio(**kwargs)
